#
# spec file for package perl-DBD-SQLite
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-DBD-SQLite
Version:        1.66
Release:        150300.3.12.1
%define cpan_name DBD-SQLite
Summary:        Self-contained RDBMS in a DBI Driver
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            http://search.cpan.org/dist/DBD-SQLite/
#Source0:        http://www.cpan.org/authors/id/I/IS/ISHIGAKI/%{cpan_name}-1.64.tar.gz
Source0:        DBD-SQLite-1.66.tar.gz
Source1:        cpanspec.yml
Patch0:         perl-DBD-SQLite-use-external-sqlite3.patch
Patch1:         0001-bsc-1203442-lowercase-test.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(DBI) >= 1.57
BuildRequires:  perl(Test::More) >= 0.88
Requires:       perl(DBI) >= 1.57
Requires:       perl(Test::More) >= 0.88
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  sqlite3
BuildRequires:  sqlite3-devel
# MANUAL END

%description
SQLite is a public domain file-based relational database engine that you
can find at the https://www.sqlite.org/ manpage.

*DBD::SQLite* is a Perl DBI driver for SQLite, that includes the entire
thing in the distribution. So in order to get a fast transaction capable
RDBMS working for your perl project you simply have to install this module,
and *nothing* else.

SQLite supports the following features:

* Implements a large subset of SQL92

  See the https://www.sqlite.org/lang.html manpage for details.

* A complete DB in a single disk file

  Everything for your database is stored in a single disk file, making it
  easier to move things around than with the DBD::CSV manpage.

* Atomic commit and rollback

  Yes, *DBD::SQLite* is small and light, but it supports full transactions!

* Extensible

  User-defined aggregate or regular functions can be registered with the
  SQL parser.

There's lots more to it, so please refer to the docs on the SQLite web
page, listed above, for SQL details. Also refer to the DBI manpage for
details on how to use DBI itself. The API works like every DBI module does.
However, currently many statement attributes are not implemented or are
limited by the typeless nature of the SQLite database.

%prep
%setup -q -n %{cpan_name}-%{version}
# PATCH-FIX-OPENSUSE use system sqlite
%patch0 -p1
%patch1 -p1
rm sqlite*
perl -i -ne 'print $_ unless m{^sqlite}' MANIFEST

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes constants.inc dbdimp_tokenizer.inc dbdimp_virtual_table.inc LICENSE README

%changelog
* Thu May 16 2024 valentin.lefebvre@suse.com
- Remove sqlite files when building with system libraries
  * Avoiding having wrong sqlite version when checking with the perl module
    [bsc#1218946]
* Tue Sep 27 2022 valentin.lefebvre@suse.com
- Fixed a test failed comparing Lowercase type data. Patch created from
  github repo commit: ba4f472e7372dbf453444c7764d1c342e7af12b8
  [bsc#1203742, 0001-bsc-1203442-lowercase-test.patch}
* Fri Mar 11 2022 josef.moellers@suse.com
- Use external sqlite3 library rather than internal code.
  [bsc#1195771, perl-DBD-SQLite-use-external-sqlite3.patch]
* Fri Mar 11 2022 josef.moellers@suse.com
- updated to 1.66
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
* Fri Mar 11 2022 josef.moellers@suse.com
- updated to 1.66
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
* Mon Aug 31 2020 timueller+perl@suse.de
- updated to 1.66
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.66 2020-08-30
  - Switched to a production version
  1.65_03 2020-07-27
  - Upgraded SQLite to 3.32.3
  1.65_02 2020-02-08
  - Upgraded SQLite to 3.31.1
  1.65_01 2020-01-18
  - Upgraded SQLite to 3.30.1
  - Added several SQL_ types as alias (pali++)
  - Fixed two initialization issues (ppisar++)
  - Allowed create_function to return an array reference
    to specify the type of the value
* Tue Aug 13 2019 coolo@suse.com
- updated to 1.64
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.64 2019-08-12
  - Switched to a production version
  1.63_05 2019-07-12
  - Upgraded SQLite to 3.29.0
  - Added sqlite_get_autocommit private method (GH#52)
  - Addded new db_config constants, notably to prohibit
    double-quoted string literals
  1.63_04 2019-05-25
  - Upgraded SQLite to 3.28.0
  - Modified doc for sqlite_db_filename which actually returns undef
    or an empty string (GH#50)
  - Fixed ->quote($blob, SQL_BLOB) to quote correctly (GH#51, pali++)
  1.63_03 2019-02-15
  - Applied a patch to fix segmentation fault on 32-bit big-endian
    platforms by Niko Tyni (GH#45)
  1.63_02 2019-02-14
  - Upgraded SQLite to 3.27.1
  - Let a URI filename test skip if SQLite is compiled with URI filename
    support (GH#47)
  1.63_01 2019-01-26
  - Made sure an internal hv is initialized (GH#45)
  - Fixed a number of tests to skip
  - Bumped up Test::More requirement
  - Replaced bundled Test::NoWarnings with Test::FailWarnings
  - Handle 'unknown' op in DBD::SQLite::VirtualTable::PerlData (Corion++)
* Sat Dec 29 2018 coolo@suse.com
- updated to 1.62
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.62 2018-12-29
  - Switched to a production version
  1.61_04 2018-12-22
  - Added sqlite_db_config method and new constants for it
  - Added sqlite_defensive option to disallow dangerous SQLite features
  - Exposed some of the hidden extended result codes
  1.61_03 2018-12-19
  - Upgraded SQLite to 3.26.0, which reportedly has a security fix
  1.61_02 2018-12-01
  - Added sqlite_backup_from_dbh/sqlite_backup_to_dbh methods
  - Introduced sqlite_prefer_numeric_type database handle attribute
    that changes the value of TYPE statement handle attribute
    from an array of string to an array of integer, as an experimental
    feature. Setting this may break your applications.
  - Changed preferred bugtracker
  1.61_01 2018-12-01
  - Added ability to configure SQLITE_MAX_LENGT with environmental
    variable (Roy Storey)
  - Added sqlite_limit database handle method to change run-time limits
  - Upgraded SQLite to 3.25.3
  - Updated constants
* Thu Dec  6 2018 coolo@suse.com
- updated to 1.60
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.60 2018-12-01
  - Switched to a production version
  1.59_03 2018-11-03
  - Added a note on the long standing bug on TYPE statement
    handle attribute
  - Applied a doc patch on Virtual::PerlData by Björn Höhrmann
    (GH-31)
  1.59_02 2018-09-30
  - Upgraded SQLite to 3.25.2
  1.59_01 2018-09-17
  - Upgraded SQLite to 3.25.0, with ALTER TABLE ... RENAME COLUMN
    and UPSERT among others
  - Added ::GetInfo (GH#32, Brendan Byrd)
  - Fix to use a PV value as a virtual table column value
    where appropriate (RT-124941)
  - Add deferrability to foreign_key_info (mohawk2)
* Thu Mar 29 2018 coolo@suse.com
- updated to 1.58
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.58 2018-03-28
  - Switched to a production version.
  1.57_01 2018-03-21
  - Made it an error to fetch attributes from a statement
    handle whose database handle is inactive (ribasushi++)
* Thu Mar  1 2018 coolo@suse.com
- updated to 1.56
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.56 2018-02-28
  - Switched to a production version.
  1.55_07 2018-01-27
  - This is a developer release to help testing DBIx::Class
  - Upgraded SQLite to 3.22.0
  - Disabled two STAT compile time options (tentatively),
    which fixes RT-124227 anyway
  1.55_06 2018-01-27
  - This is a developer release to help testing DBIx::Class
  - Downgraded SQLite to 3.19.3 because of a SQLite regression
    (RT-124227, ribasushi++)
  - Fixed some tests to adapt to a change in error format
    introduced by the latest DBI
  - Remove no warnings test from t/43_fts.t which failed under
    some environments
  1.55_05 2017-12-16
  - Implemented ParamValues statement handle attribute (RT-123886)
  1.55_04 2017-11-22
  - Updated SQLite to 3.21.0
  - Resolved #122581: statistics_info() doesn't work correctly
    (John Deighan)
  - Fixed typo (GH#26, ReneNyffenegger)
  - Silenced some warnings (GH#25, Jacques Germishuys)
  - Fixed no dot in @INC issue (GH#24, ribasushi)
  - Fixed zero-length BLOB value is retrieved as undef
    (GH#23, SATO Kentaro)
  - Fixed VirtualTable::PerlData to use new ops added in SQLite 3.21.0
    (GH#28, fschlich)
  - noted on sqlite_extended_result_codes handle attribute
  1.55_03 2017-02-14
  - Updated SQLite to 3.17.0
  1.55_02 2017-01-08
  - Updated SQLite to 3.16.2
  - Fixed statistics_info when only unique indexes were requested (Dave
    Rolsky++). GitHub #21
  1.55_01 2017-01-04
  - Updated SQLite to 3.16.0
* Sun Dec 25 2016 coolo@suse.com
- updated to 1.54
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.54 2016-12-24
  - Switched to a production version.
  - Resolved RT#119219: Trivial documentation bug in DBL::SQLite 1.52
  1.53_01 2016-11-26
  - Re-enabled perl tokenizer by calling sqlite_db_config
    if SQLite >= 3.12
* Wed Nov 16 2016 coolo@suse.com
- updated to 1.52
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.52 2016-11-15
  - Switched to a production version.
  1.51_07 2016-10-16
  - Downgraded SQLite to 3.13.0 (RT#118395)
  1.51_06 2016-10-15
  - Updated SQLite to 3.15.0
  1.51_05 2016-06-23
  - Updated SQLite to 3.13.0
  - Resolved #115465: column_info doesn't parse sizes with spaces
    (ilmari++)
  - Added two missing function declarations (rurban++)
  1.51_04 2016-03-07
  - Updated SQLite to 3.11.1, which fixed an FTS5 index
    corruption issue
  1.51_03 2016-02-20
  - No code change
  - Resolved #112220: t/62_regexp_multibyte_char_class.t fails
    for perl >= 5.22.0 and non-utf8 locale (SREZIC++)
  1.51_02 2016-02-20
  - No code change; fixed a newly added test that only passed
    under recent perls (>= 5.18)
  1.51_01 2016-02-20
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Updated to SQLite 3.11.0.
    As upstream disabled two-arg fts3_tokenizer() for security concern,
    DBD::SQLite also stopped enabling it by default. If you do need
    perl tokenizer, compile/install with SQLITE_ENABLE_FTS3_TOKENIZER
    environmental variable.
  - Applied a doc patch by Salvatore Bonaccorso
  - Enabled (experimental) FTS5
  - Fixed REGEXP function to work under sqlite_unicode correctly
    (András Farkas++)
* Sat Feb 13 2016 coolo@suse.com
- updated to 1.50
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.50 2016-02-11
  - Switched to a production version.
  1.49_08 2016-01-30
  - no significant code changes
  - Resolved RT#111558: Virtual table tests depend on enhanced
    query syntax availability (vlmarek++)
  - Ingore FTS tests if FTS is not available
  1.49_07 2016-01-21
  - Updated to SQLite 3.10.2, which fixed a case-folding bug
    in the LIKE operator introduced in SQLite 3.10.0.
  1.49_06 2016-01-15
  - Updated to SQLite 3.10.1, which fixed an old bug that could
    generate incorrect results when a scalar subquery attempts
    to use the block sorting optimization.
  1.49_05 2016-01-11
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Updated to SQLite 3.10.0.
    Because of the addition of LIKE/GLOB/REGEXP support on
    virtual tables, previous ::PerlData virtual table got broken.
    This is hopefully fixed by adding strlike/strglob functions
    to DBD::SQLite but if you use this virtual table, please
    test it carefully.
  - Now you can make a database connection read-only if you
    turn on the ReadOnly attribute when you connect. (RT #110439)
    If you set it after you connect to a database, DBD::SQLite
    warns because the database doesn't actually become read-only.
  - Improved ::Constants
  - to load DBD::SQLite by itself
  - to expose SQLITE_VERSION_NUMBER
  - introduced a few new (shorter) tags
  1.49_04 2015-11-24
  - Updated ::Constants
  - Fixed a sqlite version number in a test (GH-14; NANIS++)
  1.49_03 2015-11-05
  - Updated to SQLite 3.9.2, with JSON support
  1.49_02 2015-10-10
  - Added a workaround to resolve #106950 Extra warnings
    with savepoints (hopefully)
  - Not to run tests for table_column_metadata unless
    ENABLE_COLUMN_METADATA is set
  1.49_01 2015-08-04
  - Updated to SQLite 3.8.11.1
  - Resolved #106151 SAVEPOINT bug
  - Made sure to keep what's left in unprepared_statements when
    allow_multiple_statements is set. (GH #11)
* Sun Jun 21 2015 coolo@suse.com
- updated to 1.48
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.48 2015-06-12
  - Switched to a production version. (ISHIGAKI)
  1.47_05 2015-05-08
  - Updated to SQLite 3.8.10
  1.47_04 2015-05-02
  - Used MY_CXT instead of a global variable
  1.47_03 2015-04-16
  - Added :all to EXPORT_TAGS in ::Constants
  1.47_02 2015-04-16
  - Updated to SQLite 3.8.9
  - Added DBD::SQLite::Constants, from which you can import any
    "useful" constants into your applications.
  - Removed previous Cygwin hack as SQLite 3.8.9 compiles well again
  - Now create_function/aggregate accepts an extra bit
    (SQLITE_DETERMINISTIC) for better performance.
  1.47_01 2015-02-17
  * ** (EXPERIMENTAL) CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Commented OPTIMIZE out of WriteMakefile (RT #94207).
    If your perl is not compiled with -O2, your DBD::SQLite may
    possibly behave differently under some circumstances.
    (This release is to find notable examples from CPAN Testers).
  - Set THREADSAFE to 0 under Cygwin to cope with an upstream
    regression since 3.8.7 (GH #7).
  - Updated to SQLite 3.8.8.2
  - Resolved #35449: Fast DBH->do (ptushnik, ISHIGAKI)
* Thu Apr 16 2015 coolo@suse.com
- updated to 1.46
  see /usr/share/doc/packages/perl-DBD-SQLite/Changes
  1.46 2014-12-10
  - Switched to a production version. (ISHIGAKI)
  1.45_06 2014-11-26
  - Silenced a compile-time warning (Unescaped left brace
    in regex is deprecated) in PerlData virtual table
    under bleadperl
  1.45_05 2014-11-25
  - Updated to SQLite 3.8.7.2
  - Restored regexp support in PerlData virtual table
    by secure reimplementation using closure (DAMI++)
  1.45_04 2014-10-28
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Changed to apply quotemeta() to parameters while building
    a query for a virtual table using PerlData for security.
    (RIBASUSHI++ and MAUKE++) (DAMI, ISHIGAKI)
  1.45_03 2014-10-25
  - Fixed regression of 0 as integer (ISHIGAKI)
  1.45_02 2014-10-23
  - Improved int overflow handling under 32bit strawberry perl
    (ISHIGAKI)
  1.45_01 2014-10-22
  - Updated to SQLite 3.8.7 (ISHIGAKI)
  - Resolved #76395 (hopefully): int values over 32 bit in length
    produce an error "datatype mismatch" (ISHIGAKI)
  1.44 2014-10-22
  - Switched to a production version. (ISHIGAKI)
  1.43_09 2014-10-20
  - Resolved #99583: Legacy DOS 8.3 filename support incompatible
    with SQLITE WAL journal mode (spotted by Pat Horton) (ISHIGAKI)
  - 1.43_07/08 were not VC6 compatible (ISHIGAKI)
  1.43_08 2014-08-21
  - Updated to SQLite 3.8.6, which should fix a unique index
    issue: see http://www.sqlite.org/src/info/9a6daf340df99ba93c
    for details (ISHIGAKI)
  1.43_07 2014-07-30
  - Resolved #97598: Crash on disconnect with virtual tables (FTS4)
    (patch and test code by Rob++) (ISHIGAKI)
  1.43_06 2014-07-22
  - Fixed compile error/warning for older perls (reported by ribasushi)
    (ISHIGAKI)
  1.43_05 2014-07-21
  - No significant code changes; removed unnecessary dependencies.
  1.43_04 2014-07-21
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Resolved #96877: sql statements should be converted to utf8 (DAMI)
    If you set sqlite_unicode to true, SQL statements will be upgraded
    to avoid inconsistency between embedded params and bind params.
  - Resolved #96494: [PATCH] add SYSTEM TABLE to table_info() type
    list (MJP)
  - Supported virtual tables in Perl, and added two sample tables
    (DAMI++)
  1.43_03 2014-06-12
  - Updated to SQLite 3.8.5, which should fix query planner's
    issues in SQLite (ISHIGAKI)
  - Fixed busy_timeout to accept 0 to disable (reported by zdm)
    (ISHIGAKI)
  - Resolved #95511: primary_key_info fails to return names for
    named primary keys (Kenneth Kroenlein)
  - Resolved #96050: Segfault in disconnected sqlite_db_filename
    (reported by Alex Vandiver) (ISHIGAKI)
  1.43_02 2014-03-26
  - Limited -std=gnu99 to solaris gcc only, though it may be
    harmless in many cases (mattp++) (ISHIGAKI)
  1.43_01 2014-03-26
  - Added -std=gnu99 for solaris gcc users (reported by mattp++)
    (ISHIGAKI)
* Fri Sep 19 2014 coolo@suse.com
- updated to 1.42
  - Switched to a production version. (ISHIGAKI)
  1.41_07 2014-03-13
  - Updated to SQLite 3.8.4.1, which fixed several obscure bugs on
    "ORDER BY" or "DISTINCT". (ISHIGAKI)
  1.41_06 2014-02-12
  - Updated to SQLite 3.8.3.1, which fixed a SQLite bug in 3.8.2
    (bundled in DBD::SQLite 1.41_04/5) that could cause queries to
    omit valid out rows. (ISHIGAKI)
  1.41_05 2014-01-22
  - Resolved #92322: Failure under heavily parallelized tests
    (ISHIGAKI)
  - Disabled Test::NoWarnings in a test
  1.41_04 2014-01-12
  - Updated to SQLite 3.8.2 (ISHIGAKI)
  - Resolved #90211: Error in documentation (Felix Li)
  - Resolved #89351: DBD-SQLite won't compile on Cygwin 64 bit
    (Warren Young++) (ISHIGAKI)
  - Tweaked sqlite_see_if_its_a_number not to guess data types of
    bind values with explicit type specification (via bind_param()
    etc) (mje++, ilmari++) (ISHIGAKI)
  1.41_03 2013-09-05
  - Updated to SQLite 3.8.0.2 (ISHIGAKI)
  1.41_02 2013-08-30
  - Updated to SQLite 3.8.0.1 to resolve #88228 (RIBASUSHI++)
    (ISHIGAKI)
  1.41_01 2013-08-27
  * ** NOTICE ON NEXT GENERATION QUERY PLANNER ***
  - As of SQLite 3.8.0, SQLite's query planner has been rewritten.
    According to the author, the new query planner should give
    exactly the same result (though perhaps with a little less CPU
    time spent planning) for simple queries, and for complex
    queries, it can in many cases provide a much faster answer.
    See http://www.sqlite.org/queryplanner-ng.html for details.
  * ** NOTICE ON PARTIAL INDICES ***
  - Database files created by SQLite 3.8.0 are still readable and
    writable by prior versions, but if you use partial indices
    introduced in SQLite 3.8.0, those files become unreadable and
    unwritable by older versions of (DBD::)SQLite. They'll be
    readable/writable again by dropping partial indices.
  - Resolved #87435: PATCH: statistics_info perldoc (DDICK)
  - Resolved #87297: URI filenames in DBD::SQLite (ISHIGAKI)
* Sun Jul 28 2013 coolo@suse.com
- updated to 1.40
  - NetBSD also doesn't like the _XOPEN_SOURCE hack (ISHIGAKI)
  - Resolved #86080: PATCH: statistics_info support (DDICK)
* Wed Jul 24 2013 coolo@suse.com
- updated to 1.39
  1.39 Fri 31 May 2013
  - Production release, no changes from 1.38_05
  1.38_05 Fri 31 May 2013
  - OpenBSD doesn't like the previous _XOPEN_SOURCE hack (ISHIGAKI)
  - Disabled a unicode-related test for older perls (ISHIGAKI)
  1.38_04 Wed 29 May 2013
  - Tentatively defined _XOPEN_SOURCE under *BSD systems to see
    if it solves a compilation issue for threaded perls (ISHIGAKI)
  1.38_03 Mon 20 May 2013
  * ** NOTICE ON QUERY OPTIMIZER ENHANCEMENT ***
  - As of SQLite 3.7.15, SQLite's query optimizer was enhanced
    and the result order of a SELECT statement without an ORDER
    BY clause may be different from the one of the previous
    versions. If your applications or tests mistakenly depend
    on the arbitrary output order, they may be broken with this
    enhancement.
  - Updated to SQLite 3.7.17 (ISHIGAKI)
  - Fixed tests that mistakenly made invalid assumptions about
    the result order (ISHIGAKI)
  - Added a brief note on useful pragmata. (ISHIGAKI)
  - Resolved #85302: type fixes (ISHIGAKI)
  1.38_02 Thu 4 Apr 2013
  - Updated to SQLite 3.7.16.1 (ISHIGAKI)
  - Removed two obsolete pragma calls at login time (ISHIGAKI)
  - Resolved #80344: Set SQLITE_DISABLE_DIRSYNC on AIX (suggested
    by Steve Barnsley) (ISHIGAKI)
  - Resolved #81536: primary_key_info returns the wrong KEY_SEQ
    (VLYON)
  - Resolved #84027: Finalizer() not called in (D. Richard Hipp)
  - Resolved #84372: -Wpointer-sign warnings with utf8_hop
    (RURBAN)
  - Resolved #84373: Add test for RT #26775 "name)" key with
    DISTINCT (RURBAN/ISHIGAKI)
  - Resolved #70815: DBD::SQLite 1.33 build is broken under
    Solaris using Sun C (RURBAN)
  - Resolved #84380: Fix WINLIKE for mingw/msys (RURBAN)
  - Added a note on DBD::SQLite and File::Temp (suggested by
    TOKUHIROM) (ISHIGAKI)
  1.38_01 Mon 24 Sep 2012
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
  - Resolved #56444: immediate transaction should be on by
    default, and the doc be updated.
    If you really need the deferred transaction (which had long
    been the default), set sqlite_use_immediate_transaction
    to false explicitly. (ISHIGAKI)
  - Updated to SQLite 3.7.14 (ISHIGAKI)
  - Added support for foreign_key_info (DAMI/ISHIGAKI)
  - Added several methods to retrieve internal information such as
    table_column_metadata/db_filename/*_status (ISHIGAKI/VOVKASM)
  - Added sqlite_load_extension so that extensions can add
    functions internally (ISHIGAKI)
  - Resolved #77617: atoll () sometimes just is atol () (GAAS)
  - Resolved #48084: improper "require utf8" in tests (ISHIGAKI)
  - Resolved #77724: bug in primary_key_info with regard to column
* Thu Nov 15 2012 vcizek@suse.com
- update to 1.37
  - Updated to SQLite 3.7.12.1 (ISHIGAKI)
  - Tweaked Makefile.PL to behave better during the Bsymbolic
    check (HMBRAND)
  - Added SQLITE_WITHOUT_ZONEMALLOC for older MacOS X (ISHIGAKI)
  - Fix >32bit integer truncation and other sqlite_set_result
    condition issue (Yuriy Kaminskiy)
  - Fix integer overflow in passing argument to perl function
  - Convert unsigned -> int64 when possible (Yuriy Kaminskiy)
  - Turned datatype mismatch error (introduced in 1.34_02) into
    a warning (you can disable this warning by setting PrintWarn
    attribute to false). (ISHIGAKI)
  - Refactored sqlite_is_number to fix various corner cases
  - Downgraded SQLite to 3.7.9, as 3.7.10 turned out to be
    broken on the latest MacOS X (due to a missing symbol),
    and broke other modules that typically use temporary tables
    under a few environments too. As of this writing, would-be
    3.7.11 seems fine, but it would take another month to be
    released. (ISHIGAKI)
  * ** CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS ***
    Note that this release changed the default schema format
    number, that means newly created database files will be
    unreadable by SQLite version prior to 3.3.0 (2006-01-10)
    (or DBD::SQLite prior to 1.12) unless you explicitly issue
    "PRAGMA legacy_file_format=ON".
  - Enabled SQLITE_ENABLE_FTS4
  - Enabled SQLITE_ENABLE_STAT3
  - Resolved #73159: FTS tokenizer segfault (ISHIGAKI)
  - Resolved #73787: sqlite_see_if_its_a_number causes a buffer
    overflow (ISHIGAKI)
  - Resolved #73314 for DBD-SQLite: binding of 64bit integers fail
    on 1.34_02 (ISHIGAKI)
  - Implemented sqlite_trace and sqlite_profile methods for simpler
    tracing/profiling; use DBI_TRACE/DBI_PROFILE for more
    complicated cases (ISHIGAKI)
* Tue Feb 14 2012 jengelh@medozas.de
- Add Group: field to subpackages to allow them to build on
  distributions with older rpm
* Wed Dec 14 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Nov 29 2011 pascal.bleser@opensuse.org
- update to 1.35:
  * updated to SQLite 3.7.9
  * one small potential break case if you are using FTS4 and ^
- cumulated changes from 1.34*:
  * adding an explicit dynamic_config => 1
  * bind_param SQL_INTEGER error now actually dies with RaiseError
  * CHANGES THAT MAY POSSIBLY BREAK YOUR OLD APPLICATIONS:
  - resolved RT#67581: bind_param SQL_INTEGER numifies value;
    now DBD::SQLite croaks if you explicitly specify datatype
    (with bind_param) and datatype mismatch happens
  - datatype set in the bind_param(_array) becomes sticky now
    (as per DBI spec); this potentially affects code depending on
    current undocumented and broken behavior
  * resolved RT#71311: binding output columns as SQL_BLOB returns nothing
  * fixed binding named parameters
  * moved check for bind_ph/is_inout so it always error-out
  * don't set imp_sth->stmt to NULL on error path
  * explained an issue of rollback with unfinished statements
  * made util/getsqlite.pl work properly for SQLite 3.7.5+
  * Cookbook: don't use globals
  * resolved RT#70135 and hopefully other mod_perl/CentOS issues like RT#63873
    and RT#47983
* Wed Aug 10 2011 Greg.Freemyer@gmail.com
- Update to 1.33
  - Updated to SQLite 3.7.6.3 (ISHIGAKI)
  - Made util/getsqlite.pl state that it needs fixing to work for
    SQLite 3.7.5+ when it dies at the last step, and outline what the
    user needs to do manually instead, until getsqlite is fixed (DUNCAND)
  - Resolved #67843 for DBD-SQLite: savepoint rollback alters AC
    state (ISHIGAKI)
  - Resolved #65267 for DBD-SQLite: Add RTree support option;
    skip fts3/metadata tests if those features are disabled
    (ISHIGAKI)
  - Resolved #65267: Add RTree support option (CJFIELDS)
  - Added sqlite_see_if_its_a_number database handle attribute
    to deal with issues caused by (quoted) bind values against
    numbers such as return values from a function etc. (ISHIGAKI)
  - Made util/getsqlite.pl work with the amalg distro filename changes
    introd by SQLite 3.7.4, and still with older ones also (DUNCAND)
  - Updated to SQLite 3.7.4 (DUNCAND)
  - Resolved #61355: Fails testing in parallel (ISHIGAKI)
  - Resolved #61361: Problems building 1.31 with system SQLite (ISHIGAKI)
  - Resolved #61117: Supporting database as an alias for dbname in
    DSN (ISHIGAKI)
  - Resolved #62370: Segfaults during operations on disconnected
    handles (ISHIGAKI)
  - Resolved #61958: REGEXP should return NULL when one of its
    arguments is NULL (ISHIGAKI)
  - Removed PrintWarn tweak introduced in 1.19_09 (Tim Bunce's
    advice) (ISHIGAKI)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Sep 15 2010 chris@computersalat.de
- fix FIXME: need a way of adding our RPM_OPT_FLAGS to CFLAGS without
    overwriting its existing contents:
  o perl Makefile.PL CCFLAGS="$RPM_OPT_FLAGS"
    =>
    {__perl} Makefile.PL INSTALLDIRS=vendor OPTIMIZE="$RPM_OPT_FLAGS"
- fix devel deps
  o Req: perl = {perl_version}
* Wed Sep 15 2010 jw@novell.com
- Update to 1.31
  - Updated to SQLite 3.7.2 (DUNCAND)
  - Resolved # 60860: Slow but steady memory leak on
    last_insert_id calls (ISHIGAKI)
  - Upgraded ppport.h to the latest version (ADAMK)
  - Resolved #60698: "Test failures with SQLite 3.7", using included
    patch by Niko Tyni (ntyni@debian.org) of t/lib/Test.pm (DUNCAND)
  - Added support for FTS3 tokenizers written in Perl. Added tests
    ...
* Tue Mar 30 2010 jw@novell.com
- Update to 1.30_02
  + Updated to SQLite 3.6.23
  + Added preamble to copy sqlite3.[hc] files into a share
    directory (where you can access via File::ShareDir) to allow
    extension authors to use the same C source/header as they
    used to build DBD::SQLite itself. (ISHIGAKI)
  + numerous bugfixes and enhancements.
    May break old applications.
- added -devel package to contain the added sqlite3.[hc]
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Fri Jan  8 2010 jw@novell.com
- Update to 1.29:
  + Updated to SQLite 3.6.22
  + Removed the SQLITE_CORE and SQLITE_PRT_SZ flags
  + several bugfixes
* Tue Nov 24 2009 jw@novell.com
- 1.26_07 was released as 1.27
  No changes.
* Mon Nov 16 2009 jw@novell.com
- update to latest devel version 1.26_07
  + Updated to SQLite 3.6.20
  + Foreign keys support is once again disabled by default.
    use "PRAGMA foreign_keys = ON".
* Thu Oct 29 2009 jw@suse.de
- update to latest devel version 1.26_06
  + Major code refactoring.
  + Now DBD::SQLite supports foreign key constraints.
* Sun Oct 18 2009 jw@novell.com
- update to latest devel version 1.26_05
  - SQLite 3.6.19 (ISHIGAKI)
- using a simpler cpan_name macro to avoid parse warnings during build.
* Tue Oct 13 2009 chris@computersalat.de
- update to latest devel version 1.26_04
- move changes from spec to .changes file
* Wed Aug 19 2009 jw@suse.de
- update to latest devel version 1.26_03
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Fri Jul 24 2009 coolo@novell.com
- merge factory changes in
* Thu Jun 18 2009 chris@computersalat.de
- spec fix for perl-macros
* Thu Jun 18 2009 chris@computersalat.de
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Sun Jun 14 2009 chris@computersalat.de
- update to 1.25
- 1.25
  o Amalgamation conversion turned out to be quicker than expected.
  o Changing to a production release.  (ADAMK)
- 1.24_02
  o Merging various externally-contributed annotations from
    annocpan.org (ADAMK)
  o Created the beginnings of a DBD::SQLite::Cookbook (ADAMK)
- 1.24_01
  o Moved getsqlite.pl into util (ADAMK)
  o Switching to the RT queue instead of the RT report page that
    does nothing and just refers you to email (ADAMK)
  o Now DBD::SQLite also uses amalgamated source recommended at sqlite.org (ISHIGAKI)
  o Resolved #45166: better unicode path handling under cygwin (ISHIGAKI)
  o Resolved #45171: test failure on CentOS 4.6 (ISHIGAKI)
* Sun Apr 19 2009 jw@suse.de
- updated to stable release 1.23
* Wed Apr 15 2009 jw@suse.de
- updated to pristine 1.22_06
  * All* patches are upstreamed now. Yeah!
  Using SQLite 3.6.13 now.
* Wed Jan 14 2009 jw@suse.de
- bnc#466021 fixed.
* Thu Feb  7 2008 schwab@suse.de
- Don't call sqlite3_finalize twice.
* Sun Jan 13 2008 coolo@suse.de
- update to 1.14
- disable test suite for now
* Fri Sep  8 2006 jw@suse.de
- painless update to 1.13
* Mon May 29 2006 jw@suse.de
- update to 1.12, to make it compile again.
  Using SQLite 3.3.5 and Perl 5.8.8
* Mon Mar 13 2006 jw@suse.de
- fixed bugzilla#156965, unintialized variable.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Dec  4 2005 jw@suse.de
- update to 1.11, feature++
* Fri Dec  2 2005 jw@suse.de
- update to 1.10
  be more forgiving to sqlite3.h, it is buggy again.
* Tue Oct  4 2005 dmueller@suse.de
- add norootforbuild
* Thu Jun 30 2005 schwab@suse.de
- Fix neededforbuild.
* Wed Jun 29 2005 jw@suse.de
- initial version 1.09
  Since 1.09 it can link against a system provided sqlite library,
  but uses its own copy due to a buggy sqlite3.h
